# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/abci/v1beta2/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta2 import params_pb2 as cometbft_dot_types_dot_v1beta2_dot_params__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/abci/v1beta2/types.proto\x12\x15\x63ometbft.abci.v1beta2\x1a\x14gogoproto/gogo.proto\x1a!cometbft/abci/v1beta1/types.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a#cometbft/types/v1beta2/params.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\t\n\x07Request\x12\x38\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\".cometbft.abci.v1beta1.RequestEchoH\x00R\x04\x65\x63ho\x12;\n\x05\x66lush\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestFlushH\x00R\x05\x66lush\x12\x38\n\x04info\x18\x03 \x01(\x0b\x32\".cometbft.abci.v1beta2.RequestInfoH\x00R\x04info\x12H\n\ninit_chain\x18\x05 \x01(\x0b\x32\'.cometbft.abci.v1beta2.RequestInitChainH\x00R\tinitChain\x12;\n\x05query\x18\x06 \x01(\x0b\x32#.cometbft.abci.v1beta1.RequestQueryH\x00R\x05query\x12K\n\x0b\x62\x65gin_block\x18\x07 \x01(\x0b\x32(.cometbft.abci.v1beta2.RequestBeginBlockH\x00R\nbeginBlock\x12\x42\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32%.cometbft.abci.v1beta1.RequestCheckTxH\x00R\x07\x63heckTx\x12H\n\ndeliver_tx\x18\t \x01(\x0b\x32\'.cometbft.abci.v1beta1.RequestDeliverTxH\x00R\tdeliverTx\x12\x45\n\tend_block\x18\n \x01(\x0b\x32&.cometbft.abci.v1beta1.RequestEndBlockH\x00R\x08\x65ndBlock\x12>\n\x06\x63ommit\x18\x0b \x01(\x0b\x32$.cometbft.abci.v1beta1.RequestCommitH\x00R\x06\x63ommit\x12T\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestListSnapshotsH\x00R\rlistSnapshots\x12T\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32+.cometbft.abci.v1beta1.RequestOfferSnapshotH\x00R\rofferSnapshot\x12\x61\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32/.cometbft.abci.v1beta1.RequestLoadSnapshotChunkH\x00R\x11loadSnapshotChunk\x12\x64\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunkH\x00R\x12\x61pplySnapshotChunk\x12Z\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32-.cometbft.abci.v1beta2.RequestPrepareProposalH\x00R\x0fprepareProposal\x12Z\n\x10process_proposal\x18\x11 \x01(\x0b\x32-.cometbft.abci.v1beta2.RequestProcessProposalH\x00R\x0fprocessProposalB\x07\n\x05valueJ\x04\x08\x04\x10\x05\"\x90\x01\n\x0bRequestInfo\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12#\n\rblock_version\x18\x02 \x01(\x04R\x0c\x62lockVersion\x12\x1f\n\x0bp2p_version\x18\x03 \x01(\x04R\np2pVersion\x12!\n\x0c\x61\x62\x63i_version\x18\x04 \x01(\tR\x0b\x61\x62\x63iVersion\"\xd8\x02\n\x10RequestInitChain\x12\x38\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\x12R\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\'.cometbft.types.v1beta2.ConsensusParamsR\x0f\x63onsensusParams\x12L\n\nvalidators\x18\x04 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12&\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0cR\rappStateBytes\x12%\n\x0einitial_height\x18\x06 \x01(\x03R\rinitialHeight\"\x95\x02\n\x11RequestBeginBlock\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12<\n\x06header\x18\x02 \x01(\x0b\x32\x1e.cometbft.types.v1beta1.HeaderB\x04\xc8\xde\x1f\x00R\x06header\x12Q\n\x10last_commit_info\x18\x03 \x01(\x0b\x32!.cometbft.abci.v1beta2.CommitInfoB\x04\xc8\xde\x1f\x00R\x0elastCommitInfo\x12[\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x13\x62yzantineValidators\"\xa4\x03\n\x16RequestPrepareProposal\x12 \n\x0cmax_tx_bytes\x18\x01 \x01(\x03R\nmaxTxBytes\x12\x10\n\x03txs\x18\x02 \x03(\x0cR\x03txs\x12[\n\x11local_last_commit\x18\x03 \x01(\x0b\x32).cometbft.abci.v1beta2.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00R\x0flocalLastCommit\x12J\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\x94\x03\n\x16RequestProcessProposal\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\x12Y\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32!.cometbft.abci.v1beta2.CommitInfoB\x04\xc8\xde\x1f\x00R\x12proposedLastCommit\x12J\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\".cometbft.abci.v1beta2.MisbehaviorB\x04\xc8\xde\x1f\x00R\x0bmisbehavior\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x30\n\x14next_validators_hash\x18\x07 \x01(\x0cR\x12nextValidatorsHash\x12)\n\x10proposer_address\x18\x08 \x01(\x0cR\x0fproposerAddress\"\xba\n\n\x08Response\x12H\n\texception\x18\x01 \x01(\x0b\x32(.cometbft.abci.v1beta1.ResponseExceptionH\x00R\texception\x12\x39\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseEchoH\x00R\x04\x65\x63ho\x12<\n\x05\x66lush\x18\x03 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseFlushH\x00R\x05\x66lush\x12\x39\n\x04info\x18\x04 \x01(\x0b\x32#.cometbft.abci.v1beta1.ResponseInfoH\x00R\x04info\x12I\n\ninit_chain\x18\x06 \x01(\x0b\x32(.cometbft.abci.v1beta2.ResponseInitChainH\x00R\tinitChain\x12<\n\x05query\x18\x07 \x01(\x0b\x32$.cometbft.abci.v1beta1.ResponseQueryH\x00R\x05query\x12L\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32).cometbft.abci.v1beta2.ResponseBeginBlockH\x00R\nbeginBlock\x12\x43\n\x08\x63heck_tx\x18\t \x01(\x0b\x32&.cometbft.abci.v1beta2.ResponseCheckTxH\x00R\x07\x63heckTx\x12I\n\ndeliver_tx\x18\n \x01(\x0b\x32(.cometbft.abci.v1beta2.ResponseDeliverTxH\x00R\tdeliverTx\x12\x46\n\tend_block\x18\x0b \x01(\x0b\x32\'.cometbft.abci.v1beta2.ResponseEndBlockH\x00R\x08\x65ndBlock\x12?\n\x06\x63ommit\x18\x0c \x01(\x0b\x32%.cometbft.abci.v1beta1.ResponseCommitH\x00R\x06\x63ommit\x12U\n\x0elist_snapshots\x18\r \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseListSnapshotsH\x00R\rlistSnapshots\x12U\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32,.cometbft.abci.v1beta1.ResponseOfferSnapshotH\x00R\rofferSnapshot\x12\x62\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunkH\x00R\x11loadSnapshotChunk\x12\x65\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunkH\x00R\x12\x61pplySnapshotChunk\x12[\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponsePrepareProposalH\x00R\x0fprepareProposal\x12[\n\x10process_proposal\x18\x12 \x01(\x0b\x32..cometbft.abci.v1beta2.ResponseProcessProposalH\x00R\x0fprocessProposalB\x07\n\x05valueJ\x04\x08\x05\x10\x06\"\xd0\x01\n\x11ResponseInitChain\x12R\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\'.cometbft.types.v1beta2.ConsensusParamsR\x0f\x63onsensusParams\x12L\n\nvalidators\x18\x02 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\nvalidators\x12\x19\n\x08\x61pp_hash\x18\x03 \x01(\x0cR\x07\x61ppHash\"d\n\x12ResponseBeginBlock\x12N\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"\xe2\x02\n\x0fResponseCheckTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12N\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\x12\x16\n\x06sender\x18\t \x01(\tR\x06sender\x12\x1a\n\x08priority\x18\n \x01(\x03R\x08priority\x12#\n\rmempool_error\x18\x0b \x01(\tR\x0cmempoolError\"\x8b\x02\n\x11ResponseDeliverTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12N\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\"\x9e\x02\n\x10ResponseEndBlock\x12Y\n\x11validator_updates\x18\x01 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\x10validatorUpdates\x12_\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\'.cometbft.types.v1beta2.ConsensusParamsR\x15\x63onsensusParamUpdates\x12N\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"+\n\x17ResponsePrepareProposal\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\"\xa7\x01\n\x17ResponseProcessProposal\x12U\n\x06status\x18\x01 \x01(\x0e\x32=.cometbft.abci.v1beta2.ResponseProcessProposal.ProposalStatusR\x06status\"5\n\x0eProposalStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02\"_\n\nCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12;\n\x05votes\x18\x02 \x03(\x0b\x32\x1f.cometbft.abci.v1beta1.VoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"o\n\x12\x45xtendedCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12\x43\n\x05votes\x18\x02 \x03(\x0b\x32\'.cometbft.abci.v1beta2.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00R\x05votes\"\x80\x01\n\x05\x45vent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x63\n\nattributes\x18\x02 \x03(\x0b\x32%.cometbft.abci.v1beta2.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitemptyR\nattributes\"N\n\x0e\x45ventAttribute\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12\x14\n\x05index\x18\x03 \x01(\x08R\x05index\"\xab\x01\n\x10\x45xtendedVoteInfo\x12\x44\n\tvalidator\x18\x01 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12*\n\x11signed_last_block\x18\x02 \x01(\x08R\x0fsignedLastBlock\x12%\n\x0evote_extension\x18\x03 \x01(\x0cR\rvoteExtension\"\x8f\x02\n\x0bMisbehavior\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.cometbft.abci.v1beta2.MisbehaviorTypeR\x04type\x12\x44\n\tvalidator\x18\x02 \x01(\x0b\x32 .cometbft.abci.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00R\tvalidator\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x38\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12,\n\x12total_voting_power\x18\x05 \x01(\x03R\x10totalVotingPower*K\n\x0fMisbehaviorType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x32\xbb\x0c\n\x0f\x41\x42\x43IApplication\x12O\n\x04\x45\x63ho\x12\".cometbft.abci.v1beta1.RequestEcho\x1a#.cometbft.abci.v1beta1.ResponseEcho\x12R\n\x05\x46lush\x12#.cometbft.abci.v1beta1.RequestFlush\x1a$.cometbft.abci.v1beta1.ResponseFlush\x12O\n\x04Info\x12\".cometbft.abci.v1beta2.RequestInfo\x1a#.cometbft.abci.v1beta1.ResponseInfo\x12^\n\tDeliverTx\x12\'.cometbft.abci.v1beta1.RequestDeliverTx\x1a(.cometbft.abci.v1beta2.ResponseDeliverTx\x12X\n\x07\x43heckTx\x12%.cometbft.abci.v1beta1.RequestCheckTx\x1a&.cometbft.abci.v1beta2.ResponseCheckTx\x12R\n\x05Query\x12#.cometbft.abci.v1beta1.RequestQuery\x1a$.cometbft.abci.v1beta1.ResponseQuery\x12U\n\x06\x43ommit\x12$.cometbft.abci.v1beta1.RequestCommit\x1a%.cometbft.abci.v1beta1.ResponseCommit\x12^\n\tInitChain\x12\'.cometbft.abci.v1beta2.RequestInitChain\x1a(.cometbft.abci.v1beta2.ResponseInitChain\x12\x61\n\nBeginBlock\x12(.cometbft.abci.v1beta2.RequestBeginBlock\x1a).cometbft.abci.v1beta2.ResponseBeginBlock\x12[\n\x08\x45ndBlock\x12&.cometbft.abci.v1beta1.RequestEndBlock\x1a\'.cometbft.abci.v1beta2.ResponseEndBlock\x12j\n\rListSnapshots\x12+.cometbft.abci.v1beta1.RequestListSnapshots\x1a,.cometbft.abci.v1beta1.ResponseListSnapshots\x12j\n\rOfferSnapshot\x12+.cometbft.abci.v1beta1.RequestOfferSnapshot\x1a,.cometbft.abci.v1beta1.ResponseOfferSnapshot\x12v\n\x11LoadSnapshotChunk\x12/.cometbft.abci.v1beta1.RequestLoadSnapshotChunk\x1a\x30.cometbft.abci.v1beta1.ResponseLoadSnapshotChunk\x12y\n\x12\x41pplySnapshotChunk\x12\x30.cometbft.abci.v1beta1.RequestApplySnapshotChunk\x1a\x31.cometbft.abci.v1beta1.ResponseApplySnapshotChunk\x12p\n\x0fPrepareProposal\x12-.cometbft.abci.v1beta2.RequestPrepareProposal\x1a..cometbft.abci.v1beta2.ResponsePrepareProposal\x12p\n\x0fProcessProposal\x12-.cometbft.abci.v1beta2.RequestProcessProposal\x1a..cometbft.abci.v1beta2.ResponseProcessProposalB\xd5\x01\n\x19\x63om.cometbft.abci.v1beta2B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta2\xa2\x02\x03\x43\x41X\xaa\x02\x15\x43ometbft.Abci.V1beta2\xca\x02\x15\x43ometbft\\Abci\\V1beta2\xe2\x02!Cometbft\\Abci\\V1beta2\\GPBMetadata\xea\x02\x17\x43ometbft::Abci::V1beta2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v1beta2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.abci.v1beta2B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/abci/v1beta2\242\002\003CAX\252\002\025Cometbft.Abci.V1beta2\312\002\025Cometbft\\Abci\\V1beta2\342\002!Cometbft\\Abci\\V1beta2\\GPBMetadata\352\002\027Cometbft::Abci::V1beta2'
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['last_commit_info']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['last_commit_info']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['byzantine_validators']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['byzantine_validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPREPAREPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTPROCESSPROPOSAL'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEDELIVERTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEDELIVERTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['time']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MISBEHAVIORTYPE']._serialized_start=6731
  _globals['_MISBEHAVIORTYPE']._serialized_end=6806
  _globals['_REQUEST']._serialized_start=224
  _globals['_REQUEST']._serialized_end=1471
  _globals['_REQUESTINFO']._serialized_start=1474
  _globals['_REQUESTINFO']._serialized_end=1618
  _globals['_REQUESTINITCHAIN']._serialized_start=1621
  _globals['_REQUESTINITCHAIN']._serialized_end=1965
  _globals['_REQUESTBEGINBLOCK']._serialized_start=1968
  _globals['_REQUESTBEGINBLOCK']._serialized_end=2245
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_start=2248
  _globals['_REQUESTPREPAREPROPOSAL']._serialized_end=2668
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_start=2671
  _globals['_REQUESTPROCESSPROPOSAL']._serialized_end=3075
  _globals['_RESPONSE']._serialized_start=3078
  _globals['_RESPONSE']._serialized_end=4416
  _globals['_RESPONSEINITCHAIN']._serialized_start=4419
  _globals['_RESPONSEINITCHAIN']._serialized_end=4627
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=4629
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=4729
  _globals['_RESPONSECHECKTX']._serialized_start=4732
  _globals['_RESPONSECHECKTX']._serialized_end=5086
  _globals['_RESPONSEDELIVERTX']._serialized_start=5089
  _globals['_RESPONSEDELIVERTX']._serialized_end=5356
  _globals['_RESPONSEENDBLOCK']._serialized_start=5359
  _globals['_RESPONSEENDBLOCK']._serialized_end=5645
  _globals['_RESPONSEPREPAREPROPOSAL']._serialized_start=5647
  _globals['_RESPONSEPREPAREPROPOSAL']._serialized_end=5690
  _globals['_RESPONSEPROCESSPROPOSAL']._serialized_start=5693
  _globals['_RESPONSEPROCESSPROPOSAL']._serialized_end=5860
  _globals['_RESPONSEPROCESSPROPOSAL_PROPOSALSTATUS']._serialized_start=5807
  _globals['_RESPONSEPROCESSPROPOSAL_PROPOSALSTATUS']._serialized_end=5860
  _globals['_COMMITINFO']._serialized_start=5862
  _globals['_COMMITINFO']._serialized_end=5957
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=5959
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=6070
  _globals['_EVENT']._serialized_start=6073
  _globals['_EVENT']._serialized_end=6201
  _globals['_EVENTATTRIBUTE']._serialized_start=6203
  _globals['_EVENTATTRIBUTE']._serialized_end=6281
  _globals['_EXTENDEDVOTEINFO']._serialized_start=6284
  _globals['_EXTENDEDVOTEINFO']._serialized_end=6455
  _globals['_MISBEHAVIOR']._serialized_start=6458
  _globals['_MISBEHAVIOR']._serialized_end=6729
  _globals['_ABCIAPPLICATION']._serialized_start=6809
  _globals['_ABCIAPPLICATION']._serialized_end=8404
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.evm.v1 import tx_pb2 as injective_dot_evm_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the evm Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EthereumTx = channel.unary_unary(
                '/injective.evm.v1.Msg/EthereumTx',
                request_serializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTx.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTxResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/injective.evm.v1.Msg/UpdateParams',
                request_serializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the evm Msg service.
    """

    def EthereumTx(self, request, context):
        """EthereumTx defines a method submitting Ethereum transactions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defined a governance operation for updating the x/evm module
        parameters. The authority is hard-coded to the Cosmos SDK x/gov module
        account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EthereumTx': grpc.unary_unary_rpc_method_handler(
                    servicer.EthereumTx,
                    request_deserializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTx.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTxResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.evm.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.evm.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the evm Msg service.
    """

    @staticmethod
    def EthereumTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Msg/EthereumTx',
            injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTx.SerializeToString,
            injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Msg/UpdateParams',
            injective_dot_evm_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            injective_dot_evm_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.crypto.multisig.v1beta1 import multisig_pb2 as cosmos_dot_crypto_dot_multisig_dot_v1beta1_dot_multisig__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.tx.signing.v1beta1 import signing_pb2 as cosmos_dot_tx_dot_signing_dot_v1beta1_dot_signing__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmos/tx/v1beta1/tx.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a-cosmos/crypto/multisig/v1beta1/multisig.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\'cosmos/tx/signing/v1beta1/signing.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\x8d\x01\n\x02Tx\x12-\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x19.cosmos.tx.v1beta1.TxBodyR\x04\x62ody\x12\x38\n\tauth_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.AuthInfoR\x08\x61uthInfo\x12\x1e\n\nsignatures\x18\x03 \x03(\x0cR\nsignatures\"n\n\x05TxRaw\x12\x1d\n\nbody_bytes\x18\x01 \x01(\x0cR\tbodyBytes\x12&\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0cR\rauthInfoBytes\x12\x1e\n\nsignatures\x18\x03 \x03(\x0cR\nsignatures\"\x92\x01\n\x07SignDoc\x12\x1d\n\nbody_bytes\x18\x01 \x01(\x0cR\tbodyBytes\x12&\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0cR\rauthInfoBytes\x12\x19\n\x08\x63hain_id\x18\x03 \x01(\tR\x07\x63hainId\x12%\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04R\raccountNumber\"\xf2\x01\n\x10SignDocDirectAux\x12\x1d\n\nbody_bytes\x18\x01 \x01(\x0cR\tbodyBytes\x12\x33\n\npublic_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\tpublicKey\x12\x19\n\x08\x63hain_id\x18\x03 \x01(\tR\x07\x63hainId\x12%\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04R\raccountNumber\x12\x1a\n\x08sequence\x18\x05 \x01(\x04R\x08sequence\x12,\n\x03tip\x18\x06 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.TipB\x02\x18\x01R\x03tip\"\x95\x02\n\x06TxBody\x12\x30\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x08messages\x12\x12\n\x04memo\x18\x02 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x03 \x01(\x04R\rtimeoutHeight\x12\x42\n\x11\x65xtension_options\x18\xff\x07 \x03(\x0b\x32\x14.google.protobuf.AnyR\x10\x65xtensionOptions\x12Z\n\x1enon_critical_extension_options\x18\xff\x0f \x03(\x0b\x32\x14.google.protobuf.AnyR\x1bnonCriticalExtensionOptions\"\xa4\x01\n\x08\x41uthInfo\x12@\n\x0csigner_infos\x18\x01 \x03(\x0b\x32\x1d.cosmos.tx.v1beta1.SignerInfoR\x0bsignerInfos\x12(\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.FeeR\x03\x66\x65\x65\x12,\n\x03tip\x18\x03 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.TipB\x02\x18\x01R\x03tip\"\x97\x01\n\nSignerInfo\x12\x33\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\tpublicKey\x12\x38\n\tmode_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfoR\x08modeInfo\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\"\xe0\x02\n\x08ModeInfo\x12<\n\x06single\x18\x01 \x01(\x0b\x32\".cosmos.tx.v1beta1.ModeInfo.SingleH\x00R\x06single\x12\x39\n\x05multi\x18\x02 \x01(\x0b\x32!.cosmos.tx.v1beta1.ModeInfo.MultiH\x00R\x05multi\x1a\x41\n\x06Single\x12\x37\n\x04mode\x18\x01 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignModeR\x04mode\x1a\x90\x01\n\x05Multi\x12K\n\x08\x62itarray\x18\x01 \x01(\x0b\x32/.cosmos.crypto.multisig.v1beta1.CompactBitArrayR\x08\x62itarray\x12:\n\nmode_infos\x18\x02 \x03(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfoR\tmodeInfosB\x05\n\x03sum\"\x81\x02\n\x03\x46\x65\x65\x12y\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x06\x61mount\x12\x1b\n\tgas_limit\x18\x02 \x01(\x04R\x08gasLimit\x12.\n\x05payer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05payer\x12\x32\n\x07granter\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07granter\"\xb6\x01\n\x03Tip\x12y\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01R\x06\x61mount\x12\x30\n\x06tipper\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06tipper:\x02\x18\x01\"\xce\x01\n\rAuxSignerData\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress\x12>\n\x08sign_doc\x18\x02 \x01(\x0b\x32#.cosmos.tx.v1beta1.SignDocDirectAuxR\x07signDoc\x12\x37\n\x04mode\x18\x03 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignModeR\x04mode\x12\x10\n\x03sig\x18\x04 \x01(\x0cR\x03sigB\xad\x01\n\x15\x63om.cosmos.tx.v1beta1B\x07TxProtoP\x01Z%github.com/cosmos/cosmos-sdk/types/tx\xa2\x02\x03\x43TX\xaa\x02\x11\x43osmos.Tx.V1beta1\xca\x02\x11\x43osmos\\Tx\\V1beta1\xe2\x02\x1d\x43osmos\\Tx\\V1beta1\\GPBMetadata\xea\x02\x13\x43osmos::Tx::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cosmos.tx.v1beta1B\007TxProtoP\001Z%github.com/cosmos/cosmos-sdk/types/tx\242\002\003CTX\252\002\021Cosmos.Tx.V1beta1\312\002\021Cosmos\\Tx\\V1beta1\342\002\035Cosmos\\Tx\\V1beta1\\GPBMetadata\352\002\023Cosmos::Tx::V1beta1'
  _globals['_SIGNDOCDIRECTAUX'].fields_by_name['tip']._loaded_options = None
  _globals['_SIGNDOCDIRECTAUX'].fields_by_name['tip']._serialized_options = b'\030\001'
  _globals['_AUTHINFO'].fields_by_name['tip']._loaded_options = None
  _globals['_AUTHINFO'].fields_by_name['tip']._serialized_options = b'\030\001'
  _globals['_FEE'].fields_by_name['amount']._loaded_options = None
  _globals['_FEE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_FEE'].fields_by_name['payer']._loaded_options = None
  _globals['_FEE'].fields_by_name['payer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_FEE'].fields_by_name['granter']._loaded_options = None
  _globals['_FEE'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_TIP'].fields_by_name['amount']._loaded_options = None
  _globals['_TIP'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_TIP'].fields_by_name['tipper']._loaded_options = None
  _globals['_TIP'].fields_by_name['tipper']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_TIP']._loaded_options = None
  _globals['_TIP']._serialized_options = b'\030\001'
  _globals['_AUXSIGNERDATA'].fields_by_name['address']._loaded_options = None
  _globals['_AUXSIGNERDATA'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_TX']._serialized_start=265
  _globals['_TX']._serialized_end=406
  _globals['_TXRAW']._serialized_start=408
  _globals['_TXRAW']._serialized_end=518
  _globals['_SIGNDOC']._serialized_start=521
  _globals['_SIGNDOC']._serialized_end=667
  _globals['_SIGNDOCDIRECTAUX']._serialized_start=670
  _globals['_SIGNDOCDIRECTAUX']._serialized_end=912
  _globals['_TXBODY']._serialized_start=915
  _globals['_TXBODY']._serialized_end=1192
  _globals['_AUTHINFO']._serialized_start=1195
  _globals['_AUTHINFO']._serialized_end=1359
  _globals['_SIGNERINFO']._serialized_start=1362
  _globals['_SIGNERINFO']._serialized_end=1513
  _globals['_MODEINFO']._serialized_start=1516
  _globals['_MODEINFO']._serialized_end=1868
  _globals['_MODEINFO_SINGLE']._serialized_start=1649
  _globals['_MODEINFO_SINGLE']._serialized_end=1714
  _globals['_MODEINFO_MULTI']._serialized_start=1717
  _globals['_MODEINFO_MULTI']._serialized_end=1861
  _globals['_FEE']._serialized_start=1871
  _globals['_FEE']._serialized_end=2128
  _globals['_TIP']._serialized_start=2131
  _globals['_TIP']._serialized_end=2313
  _globals['_AUXSIGNERDATA']._serialized_start=2316
  _globals['_AUXSIGNERDATA']._serialized_end=2522
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/datetime.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agoogle/type/datetime.proto\x12\x0bgoogle.type\x1a\x1egoogle/protobuf/duration.proto\"\xa7\x02\n\x08\x44\x61teTime\x12\x12\n\x04year\x18\x01 \x01(\x05R\x04year\x12\x14\n\x05month\x18\x02 \x01(\x05R\x05month\x12\x10\n\x03\x64\x61y\x18\x03 \x01(\x05R\x03\x64\x61y\x12\x14\n\x05hours\x18\x04 \x01(\x05R\x05hours\x12\x18\n\x07minutes\x18\x05 \x01(\x05R\x07minutes\x12\x18\n\x07seconds\x18\x06 \x01(\x05R\x07seconds\x12\x14\n\x05nanos\x18\x07 \x01(\x05R\x05nanos\x12:\n\nutc_offset\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\tutcOffset\x12\x34\n\ttime_zone\x18\t \x01(\x0b\x32\x15.google.type.TimeZoneH\x00R\x08timeZoneB\r\n\x0btime_offset\"4\n\x08TimeZone\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07version\x18\x02 \x01(\tR\x07versionB\xae\x01\n\x0f\x63om.google.typeB\rDatetimeProtoP\x01Z<google.golang.org/genproto/googleapis/type/datetime;datetime\xf8\x01\x01\xa2\x02\x03GTX\xaa\x02\x0bGoogle.Type\xca\x02\x0bGoogle\\Type\xe2\x02\x17Google\\Type\\GPBMetadata\xea\x02\x0cGoogle::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.datetime_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\rDatetimeProtoP\001Z<google.golang.org/genproto/googleapis/type/datetime;datetime\370\001\001\242\002\003GTX\252\002\013Google.Type\312\002\013Google\\Type\342\002\027Google\\Type\\GPBMetadata\352\002\014Google::Type'
  _globals['_DATETIME']._serialized_start=76
  _globals['_DATETIME']._serialized_end=371
  _globals['_TIMEZONE']._serialized_start=373
  _globals['_TIMEZONE']._serialized_end=425
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_trading_rpc_pb2 as exchange_dot_injective__trading__rpc__pb2


class InjectiveTradingRPCStub(object):
    """InjectiveTradingStrategiesRPC defined a gRPC service for Injective Trading
    Strategies.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListTradingStrategies = channel.unary_unary(
                '/injective_trading_rpc.InjectiveTradingRPC/ListTradingStrategies',
                request_serializer=exchange_dot_injective__trading__rpc__pb2.ListTradingStrategiesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__trading__rpc__pb2.ListTradingStrategiesResponse.FromString,
                _registered_method=True)
        self.GetTradingStats = channel.unary_unary(
                '/injective_trading_rpc.InjectiveTradingRPC/GetTradingStats',
                request_serializer=exchange_dot_injective__trading__rpc__pb2.GetTradingStatsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__trading__rpc__pb2.GetTradingStatsResponse.FromString,
                _registered_method=True)
        self.StreamStrategy = channel.unary_stream(
                '/injective_trading_rpc.InjectiveTradingRPC/StreamStrategy',
                request_serializer=exchange_dot_injective__trading__rpc__pb2.StreamStrategyRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__trading__rpc__pb2.StreamStrategyResponse.FromString,
                _registered_method=True)


class InjectiveTradingRPCServicer(object):
    """InjectiveTradingStrategiesRPC defined a gRPC service for Injective Trading
    Strategies.
    """

    def ListTradingStrategies(self, request, context):
        """Lists all trading strategies
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTradingStats(self, request, context):
        """GetStats returns global statistics in the last 24hs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamStrategy(self, request, context):
        """StreamStrategy streams the trading strategies on state change
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveTradingRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListTradingStrategies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTradingStrategies,
                    request_deserializer=exchange_dot_injective__trading__rpc__pb2.ListTradingStrategiesRequest.FromString,
                    response_serializer=exchange_dot_injective__trading__rpc__pb2.ListTradingStrategiesResponse.SerializeToString,
            ),
            'GetTradingStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTradingStats,
                    request_deserializer=exchange_dot_injective__trading__rpc__pb2.GetTradingStatsRequest.FromString,
                    response_serializer=exchange_dot_injective__trading__rpc__pb2.GetTradingStatsResponse.SerializeToString,
            ),
            'StreamStrategy': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamStrategy,
                    request_deserializer=exchange_dot_injective__trading__rpc__pb2.StreamStrategyRequest.FromString,
                    response_serializer=exchange_dot_injective__trading__rpc__pb2.StreamStrategyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_trading_rpc.InjectiveTradingRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_trading_rpc.InjectiveTradingRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveTradingRPC(object):
    """InjectiveTradingStrategiesRPC defined a gRPC service for Injective Trading
    Strategies.
    """

    @staticmethod
    def ListTradingStrategies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_trading_rpc.InjectiveTradingRPC/ListTradingStrategies',
            exchange_dot_injective__trading__rpc__pb2.ListTradingStrategiesRequest.SerializeToString,
            exchange_dot_injective__trading__rpc__pb2.ListTradingStrategiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTradingStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_trading_rpc.InjectiveTradingRPC/GetTradingStats',
            exchange_dot_injective__trading__rpc__pb2.GetTradingStatsRequest.SerializeToString,
            exchange_dot_injective__trading__rpc__pb2.GetTradingStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamStrategy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/injective_trading_rpc.InjectiveTradingRPC/StreamStrategy',
            exchange_dot_injective__trading__rpc__pb2.StreamStrategyRequest.SerializeToString,
            exchange_dot_injective__trading__rpc__pb2.StreamStrategyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from dataclasses import dataclass
from decimal import Decimal

from pyinjective.constant import ADDITIONAL_CHAIN_FORMAT_DECIMALS


@dataclass(eq=True, frozen=True)
class Token:
    name: str
    symbol: str
    denom: str
    address: str
    decimals: int
    logo: str
    updated: int
    unique_symbol: str

    @staticmethod
    def convert_value_to_extended_decimal_format(value: Decimal) -> Decimal:
        return value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

    @staticmethod
    def convert_value_from_extended_decimal_format(value: Decimal) -> Decimal:
        return value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

    def chain_formatted_value(self, human_readable_value: Decimal) -> Decimal:
        return human_readable_value * Decimal(f"1e{self.decimals}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/state/v1beta3/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.state.v1beta1 import types_pb2 as cometbft_dot_state_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta1 import types_pb2 as cometbft_dot_abci_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta2 import types_pb2 as cometbft_dot_abci_dot_v1beta2_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta3 import types_pb2 as cometbft_dot_abci_dot_v1beta3_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1beta1 import validator_pb2 as cometbft_dot_types_dot_v1beta1_dot_validator__pb2
from pyinjective.proto.cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cometbft/state/v1beta3/types.proto\x12\x16\x63ometbft.state.v1beta3\x1a\"cometbft/state/v1beta1/types.proto\x1a!cometbft/abci/v1beta1/types.proto\x1a!cometbft/abci/v1beta2/types.proto\x1a!cometbft/abci/v1beta3/types.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a&cometbft/types/v1beta1/validator.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x01\n\x13LegacyABCIResponses\x12\x44\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResultR\ndeliverTxs\x12\x45\n\tend_block\x18\x02 \x01(\x0b\x32(.cometbft.state.v1beta3.ResponseEndBlockR\x08\x65ndBlock\x12K\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32*.cometbft.state.v1beta3.ResponseBeginBlockR\nbeginBlock\"d\n\x12ResponseBeginBlock\x12N\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"\x99\x02\n\x10ResponseEndBlock\x12Y\n\x11validator_updates\x18\x01 \x03(\x0b\x32&.cometbft.abci.v1beta1.ValidatorUpdateB\x04\xc8\xde\x1f\x00R\x10validatorUpdates\x12Z\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsR\x15\x63onsensusParamUpdates\x12N\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1c.cometbft.abci.v1beta2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitemptyR\x06\x65vents\"\x9a\x01\n\x13\x43onsensusParamsInfo\x12S\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusParams\x12.\n\x13last_height_changed\x18\x02 \x01(\x03R\x11lastHeightChanged\"\xf2\x01\n\x11\x41\x42\x43IResponsesInfo\x12_\n\x15legacy_abci_responses\x18\x01 \x01(\x0b\x32+.cometbft.state.v1beta3.LegacyABCIResponsesR\x13legacyAbciResponses\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x64\n\x17response_finalize_block\x18\x03 \x01(\x0b\x32,.cometbft.abci.v1beta3.ResponseFinalizeBlockR\x15responseFinalizeBlock\"\x80\x07\n\x05State\x12?\n\x07version\x18\x01 \x01(\x0b\x32\x1f.cometbft.state.v1beta1.VersionB\x04\xc8\xde\x1f\x00R\x07version\x12&\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDR\x07\x63hainId\x12%\n\x0einitial_height\x18\x0e \x01(\x03R\rinitialHeight\x12*\n\x11last_block_height\x18\x03 \x01(\x03R\x0flastBlockHeight\x12X\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x1f.cometbft.types.v1beta1.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockIDR\x0blastBlockId\x12L\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\rlastBlockTime\x12M\n\x0fnext_validators\x18\x06 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0enextValidators\x12\x44\n\nvalidators\x18\x07 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\nvalidators\x12M\n\x0flast_validators\x18\x08 \x01(\x0b\x32$.cometbft.types.v1beta1.ValidatorSetR\x0elastValidators\x12\x43\n\x1elast_height_validators_changed\x18\t \x01(\x03R\x1blastHeightValidatorsChanged\x12S\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusParams\x12N\n$last_height_consensus_params_changed\x18\x0b \x01(\x03R lastHeightConsensusParamsChanged\x12*\n\x11last_results_hash\x18\x0c \x01(\x0cR\x0flastResultsHash\x12\x19\n\x08\x61pp_hash\x18\r \x01(\x0cR\x07\x61ppHashB\xdb\x01\n\x1a\x63om.cometbft.state.v1beta3B\nTypesProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta3\xa2\x02\x03\x43SX\xaa\x02\x16\x43ometbft.State.V1beta3\xca\x02\x16\x43ometbft\\State\\V1beta3\xe2\x02\"Cometbft\\State\\V1beta3\\GPBMetadata\xea\x02\x18\x43ometbft::State::V1beta3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.state.v1beta3.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.state.v1beta3B\nTypesProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/state/v1beta3\242\002\003CSX\252\002\026Cometbft.State.V1beta3\312\002\026Cometbft\\State\\V1beta3\342\002\"Cometbft\\State\\V1beta3\\GPBMetadata\352\002\030Cometbft::State::V1beta3'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['version']._loaded_options = None
  _globals['_STATE'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_STATE'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _globals['_STATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STATE'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_STATE'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_LEGACYABCIRESPONSES']._serialized_start=367
  _globals['_LEGACYABCIRESPONSES']._serialized_end=606
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=608
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=708
  _globals['_RESPONSEENDBLOCK']._serialized_start=711
  _globals['_RESPONSEENDBLOCK']._serialized_end=992
  _globals['_CONSENSUSPARAMSINFO']._serialized_start=995
  _globals['_CONSENSUSPARAMSINFO']._serialized_end=1149
  _globals['_ABCIRESPONSESINFO']._serialized_start=1152
  _globals['_ABCIRESPONSESINFO']._serialized_end=1394
  _globals['_STATE']._serialized_start=1397
  _globals['_STATE']._serialized_end=2293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/eval.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api.expr.v1beta1 import value_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/api/expr/v1beta1/eval.proto\x12\x17google.api.expr.v1beta1\x1a#google/api/expr/v1beta1/value.proto\x1a\x17google/rpc/status.proto\"\xe0\x01\n\tEvalState\x12:\n\x06values\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.ExprValueR\x06values\x12\x43\n\x07results\x18\x03 \x03(\x0b\x32).google.api.expr.v1beta1.EvalState.ResultR\x07results\x1aR\n\x06Result\x12\x32\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.IdRefR\x04\x65xpr\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value\"\xc7\x01\n\tExprValue\x12\x36\n\x05value\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.ValueH\x00R\x05value\x12\x39\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.ErrorSetH\x00R\x05\x65rror\x12?\n\x07unknown\x18\x03 \x01(\x0b\x32#.google.api.expr.v1beta1.UnknownSetH\x00R\x07unknownB\x06\n\x04kind\"6\n\x08\x45rrorSet\x12*\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x12.google.rpc.StatusR\x06\x65rrors\"B\n\nUnknownSet\x12\x34\n\x05\x65xprs\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1beta1.IdRefR\x05\x65xprs\"\x17\n\x05IdRef\x12\x0e\n\x02id\x18\x01 \x01(\x05R\x02idB\xe7\x01\n\x1b\x63om.google.api.expr.v1beta1B\tEvalProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x17Google.Api.Expr.V1beta1\xca\x02\x17Google\\Api\\Expr\\V1beta1\xe2\x02#Google\\Api\\Expr\\V1beta1\\GPBMetadata\xea\x02\x1aGoogle::Api::Expr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.eval_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.google.api.expr.v1beta1B\tEvalProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001\242\002\003GAE\252\002\027Google.Api.Expr.V1beta1\312\002\027Google\\Api\\Expr\\V1beta1\342\002#Google\\Api\\Expr\\V1beta1\\GPBMetadata\352\002\032Google::Api::Expr::V1beta1'
  _globals['_EVALSTATE']._serialized_start=126
  _globals['_EVALSTATE']._serialized_end=350
  _globals['_EVALSTATE_RESULT']._serialized_start=268
  _globals['_EVALSTATE_RESULT']._serialized_end=350
  _globals['_EXPRVALUE']._serialized_start=353
  _globals['_EXPRVALUE']._serialized_end=552
  _globals['_ERRORSET']._serialized_start=554
  _globals['_ERRORSET']._serialized_end=608
  _globals['_UNKNOWNSET']._serialized_start=610
  _globals['_UNKNOWNSET']._serialized_end=676
  _globals['_IDREF']._serialized_start=678
  _globals['_IDREF']._serialized_end=701
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cometbft.rpc.grpc.v1beta1 import types_pb2 as cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.rpc.grpc.v1beta3 import types_pb2 as cometbft_dot_rpc_dot_grpc_dot_v1beta3_dot_types__pb2


class BroadcastAPIStub(object):
    """BroadcastAPI is an API for broadcasting transactions.

    Deprecated: This API will be superseded by a more comprehensive gRPC-based
    broadcast API, and is scheduled for removal after v0.38.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/cometbft.rpc.grpc.v1beta3.BroadcastAPI/Ping',
                request_serializer=cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.RequestPing.SerializeToString,
                response_deserializer=cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.ResponsePing.FromString,
                _registered_method=True)
        self.BroadcastTx = channel.unary_unary(
                '/cometbft.rpc.grpc.v1beta3.BroadcastAPI/BroadcastTx',
                request_serializer=cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.RequestBroadcastTx.SerializeToString,
                response_deserializer=cometbft_dot_rpc_dot_grpc_dot_v1beta3_dot_types__pb2.ResponseBroadcastTx.FromString,
                _registered_method=True)


class BroadcastAPIServicer(object):
    """BroadcastAPI is an API for broadcasting transactions.

    Deprecated: This API will be superseded by a more comprehensive gRPC-based
    broadcast API, and is scheduled for removal after v0.38.
    """

    def Ping(self, request, context):
        """Ping the connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastTx(self, request, context):
        """BroadcastTx broadcasts a transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BroadcastAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.RequestPing.FromString,
                    response_serializer=cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.ResponsePing.SerializeToString,
            ),
            'BroadcastTx': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastTx,
                    request_deserializer=cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.RequestBroadcastTx.FromString,
                    response_serializer=cometbft_dot_rpc_dot_grpc_dot_v1beta3_dot_types__pb2.ResponseBroadcastTx.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cometbft.rpc.grpc.v1beta3.BroadcastAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cometbft.rpc.grpc.v1beta3.BroadcastAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class BroadcastAPI(object):
    """BroadcastAPI is an API for broadcasting transactions.

    Deprecated: This API will be superseded by a more comprehensive gRPC-based
    broadcast API, and is scheduled for removal after v0.38.
    """

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.rpc.grpc.v1beta3.BroadcastAPI/Ping',
            cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.RequestPing.SerializeToString,
            cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.ResponsePing.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BroadcastTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.rpc.grpc.v1beta3.BroadcastAPI/BroadcastTx',
            cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2.RequestBroadcastTx.SerializeToString,
            cometbft_dot_rpc_dot_grpc_dot_v1beta3_dot_types__pb2.ResponseBroadcastTx.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
